@@ -7,6 +7,11 @@
 import os
 import re
 
+# Patterns of files not to scan.
+# List of typically plaintext entries with * and ? wildcards.
+# Plays nice with additional --exclude=pattern command-line arguments.
+excludes = []
+
 
 # pattern tuples contain
 # (description, [match_all_patterns], [match_any_pattern], [match_exclude_pattern])
